pub struct FeatureHasher { /* private fields */ }Expand description
Feature hasher (hashing trick) for text classification
Maps tokens to a fixed-size feature vector using hashing, avoiding the need to maintain a vocabulary dictionary. This is memory-efficient for large vocabularies.
Implementations
Sourceimpl FeatureHasher
impl FeatureHasher
Sourcepub fn new(n_features: usize) -> Self
pub fn new(n_features: usize) -> Self
Create a new feature hasher with the specified number of features
Sourcepub fn transform_text(&self, text: &str) -> Result<Array1<f64>>
pub fn transform_text(&self, text: &str) -> Result<Array1<f64>>
Transform a single text into a hashed feature vector
Sourcepub fn transform_batch(&self, texts: &[&str]) -> Result<Array2<f64>>
pub fn transform_batch(&self, texts: &[&str]) -> Result<Array2<f64>>
Transform multiple texts into a feature matrix
Sourcepub fn num_features(&self) -> usize
pub fn num_features(&self) -> usize
Get the number of features