pub struct CorrelatedTopicModel {
pub config: CtmConfig,
/* private fields */
}Expand description
Correlated Topic Model estimator.
Fit with CorrelatedTopicModel::fit; the fitted result is returned as
a CtmResult value (the model itself is stateless after construction).
Fields
config: CtmConfigModel configuration.
Implementations
Sourcepub fn new(config: CtmConfig) -> Self
pub fn new(config: CtmConfig) -> Self
Construct a new (unfitted) CTM with the given configuration.
Sourcepub fn fitted_result(&self) -> Option<&CtmResult>
pub fn fitted_result(&self) -> Option<&CtmResult>
Return a reference to the fitted result, if available.
Sourcepub fn fit_and_store(
&mut self,
doc_counts_list: &[Vec<f64>],
vocab_size: usize,
) -> Result<&CtmResult>
pub fn fit_and_store( &mut self, doc_counts_list: &[Vec<f64>], vocab_size: usize, ) -> Result<&CtmResult>
Fit the model and store the result internally, also returning it.