pub struct RstNode {
pub sentence_index: usize,
pub text: String,
pub relation_to_parent: Option<DiscourseRelation>,
pub children: Vec<RstNode>,
}Expand description
A node in a simplified Rhetorical Structure Theory tree.
Fields
sentence_index: usizeIndex of the sentence in the original document (0-based).
text: StringThe surface text of the sentence.
relation_to_parent: Option<DiscourseRelation>The discourse relation from this node’s parent to this node.
children: Vec<RstNode>Child nodes (satellite segments).