pub struct DynamicTopicModel {
pub config: DtmConfig,
/* private fields */
}Expand description
Dynamic Topic Model estimator.
Fit via DynamicTopicModel::fit; the result is returned as a DtmResult.
Fields
config: DtmConfigModel configuration.
Implementations
Sourceimpl DynamicTopicModel
impl DynamicTopicModel
Sourceimpl DynamicTopicModel
impl DynamicTopicModel
Sourcepub fn new(config: DtmConfig) -> Self
pub fn new(config: DtmConfig) -> Self
Construct a new (unfitted) DTM with the given configuration.
Sourcepub fn fitted_result(&self) -> Option<&DtmResult>
pub fn fitted_result(&self) -> Option<&DtmResult>
Return a reference to the fitted result, if available.
Sourcepub fn fit_and_store(
&mut self,
docs_by_time: &[Vec<Vec<f64>>],
vocab_size: usize,
) -> Result<&DtmResult>
pub fn fit_and_store( &mut self, docs_by_time: &[Vec<Vec<f64>>], vocab_size: usize, ) -> Result<&DtmResult>
Fit the model and store the result internally, also returning it.