#[non_exhaustive]pub struct UnicodeBpeConfig {
pub vocab_size: usize,
pub min_frequency: usize,
pub normalize: bool,
pub byte_fallback: bool,
}Expand description
Configuration for the Unicode-aware BPE tokenizer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vocab_size: usizeTarget vocabulary size (base chars + merge operations).
min_frequency: usizeMinimum pair frequency for a merge operation to be kept.
normalize: boolApply NFC-style normalization (simplified: recompose via canonical form).
byte_fallback: boolRepresent characters absent from the training vocabulary as <0xHH> byte tokens.