pub struct StatisticalCorrector { /* private fields */ }Expand description
Statistical spelling corrector
Implementations
Sourceimpl StatisticalCorrector
impl StatisticalCorrector
Sourcepub fn new(config: StatisticalCorrectorConfig) -> Self
pub fn new(config: StatisticalCorrectorConfig) -> Self
Create a new statistical spelling corrector with the given configuration
Sourcepub fn from_dictionary_corrector(dictcorrector: &DictionaryCorrector) -> Self
pub fn from_dictionary_corrector(dictcorrector: &DictionaryCorrector) -> Self
Create a statistical corrector from a base dictionary corrector
Sourcepub fn add_corpus_file<P: AsRef<Path>>(&mut self, path: P) -> Result<()>
pub fn add_corpus_file<P: AsRef<Path>>(&mut self, path: P) -> Result<()>
Add a corpus file to train the language model
Sourcepub fn add_trainingtext(&mut self, text: &str)
pub fn add_trainingtext(&mut self, text: &str)
Add text to train the language model
Sourcepub fn set_language_model(&mut self, model: NGramModel)
pub fn set_language_model(&mut self, model: NGramModel)
Set the language model
Sourcepub fn set_error_model(&mut self, model: ErrorModel)
pub fn set_error_model(&mut self, model: ErrorModel)
Set the error model
Sourcepub fn set_metric<M: StringMetric + Send + Sync + 'static>(&mut self, metric: M)
pub fn set_metric<M: StringMetric + Send + Sync + 'static>(&mut self, metric: M)
Set the string metric to use for similarity calculations
Sourcepub fn set_config(&mut self, config: StatisticalCorrectorConfig)
pub fn set_config(&mut self, config: StatisticalCorrectorConfig)
Set the configuration
Sourcepub fn correct_sentence(&self, sentence: &str) -> Result<String>
pub fn correct_sentence(&self, sentence: &str) -> Result<String>
Correct a sentence using a context-aware approach
Sourcepub fn remove_word(&mut self, word: &str)
pub fn remove_word(&mut self, word: &str)
Remove a word from the dictionary
Sourcepub fn dictionary_size(&self) -> usize
pub fn dictionary_size(&self) -> usize
Get the total number of words in the dictionary
Sourcepub fn vocabulary_size(&self) -> usize
pub fn vocabulary_size(&self) -> usize
Get the vocabulary size of the language model